@@ -52,6 +52,16 @@ public abstract class A3Object {
         upperDirection = d.upperDirection;
     }
 
+    /**
+     * A3Canvasなどにaddされる直前に呼び出されるメソッドで、
+     * 各種初期設定を行う。
+     * このメソッドを上書きする場合はsuper.init();を
+     * 記述してスーパークラスでの処理をする必要がある。
+     */
+    protected void init() {
+        behavior.init();
+    }
+
     /**
      * behaviorの働きのON、OFFを設定します。onにすると
      * 自動補完機能が有効になり、座標の変更などの表示が
