@@ -15,6 +15,9 @@ import org.w3c.dom.NamedNodeMap;
 //import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 import org.w3c.dom.Text;
+
+import com.sun.j3d.loaders.Scene;
+
 import javax.xml.xpath.*;
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
@@ -37,10 +40,13 @@ class Action3DData {
         if (isInitialized==true)
             return;
         try {
-            loader = new VrmlLoader(VrmlLoader.LOAD_VIEW_GROUPS|
-                                    VrmlLoader.LOAD_SOUND_NODES|
-                                    VrmlLoader.LOAD_LIGHT_NODES|
-                                    VrmlLoader.LOAD_FOG_NODES);
+            loader = new VrmlLoader();
+            //j3d-vrml97-0.1.0のAPIによればVrmlLoaderのコンストラクタの引数は
+            //さしあたり無視されるということらしい．
+            //loader = new VrmlLoader(VrmlLoader.LOAD_VIEW_GROUPS|
+            //                        VrmlLoader.LOAD_SOUND_NODES|
+            //                        VrmlLoader.LOAD_LIGHT_NODES|
+            //                        VrmlLoader.LOAD_FOG_NODES);
         } catch(Exception e) {
             System.out.println("Action3DData.initAction3DData(). gaha!");
             e.printStackTrace();
@@ -607,7 +613,16 @@ class Action3DData {
             Transform3D t = new Transform3D();
             //このにp.scale,offset,rotの処理を書く
             TransformGroup tg = new TransformGroup(t);
-            tg.addChild(loader.load(wrlURL).getSceneGroup());
+            Scene scene = loader.load(wrlURL);
+            //以下背景と霧を読み込むためのハックなのだが、
+            //SharedGroupには追加できないのでだめだった。
+            //Background[] bs = scene.getBackgroundNodes();
+            //for (int i=0;i<bs.length;i++)
+            //    tg.addChild(bs[i].cloneNode(false));
+            //Fog fogs[] = scene.getFogNodes();
+            //for (int i=0;i<fogs.length;i++)
+            //    tg.addChild(fogs[i].cloneNode(false));
+            tg.addChild(scene.getSceneGroup());
             sg.addChild(tg);
             //sg.compile();
             shapes.put(p.fileName,sg);
