@@ -28,6 +28,7 @@ class ActionBehavior extends Behavior implements Cloneable {
     long timeOffset = 0;
     long pauseTime;
     Action3D a3;
+    long previousTime;
 
     public ActionBehavior(Action3D action3d,Action3DData action3DData) {
         a3 = action3d;
@@ -45,13 +46,24 @@ class ActionBehavior extends Behavior implements Cloneable {
         allBranchGroup.addChild(a3Data.getNode());
         allBranchGroup.addChild(this);
     }
-
+    void init() {
+        synchronized (actionQueue) {
+            //gaha;
+            actionNo = actionQueue.remove(0);
+            //a3Data.allActionSwitch.setWhichChild(actionNo);
+            Node n = a3Data.actions[actionNo].getRootGroup();
+            a3Data.allActionBranchGroup.removeAllChildren();
+            a3Data.allActionBranchGroup.addChild(n);
+            a3Data.actions[actionNo].start();
+        }
+    }
     public void initialize() {
         if (elapsedTime==0) //<-- なんでこれが必要なのか
             return;         //<-- わからない
         WakeupOnElapsedTime w = new WakeupOnElapsedTime(elapsedTime);
         wakeupOn(w);
         timeOffset = System.currentTimeMillis();
+        previousTime = -1;
     }
     @SuppressWarnings("unchecked")
     public void processStimulus(Enumeration criteria) {
@@ -89,6 +101,7 @@ class ActionBehavior extends Behavior implements Cloneable {
                     a3Data.actions[actionNo].start();
                     immediatelyFlag = false;
                     timeOffset = System.currentTimeMillis();
+                    previousTime = -1;
                     loopFlag = a3Data.actions[actionNo].loopFlag;
                     motionLength = (long)(a3Data.actions[actionNo].getMotionLength()*1000.0);
                     elapsedTime = (int)(a3Data.actions[actionNo].motion.getDefaultFrameTime()*1000.0);
@@ -103,6 +116,7 @@ class ActionBehavior extends Behavior implements Cloneable {
                     a3Data.allActionBranchGroup.addChild(n);
                     a3Data.actions[actionNo].start();
                     timeOffset = System.currentTimeMillis();
+                    previousTime = -1;
                     loopFlag = a3Data.actions[actionNo].loopFlag;
                     motionLength = (long)(a3Data.actions[actionNo].getMotionLength()*1000.0);
                     elapsedTime = (int)(a3Data.actions[actionNo].motion.getDefaultFrameTime()*1000.0);
@@ -117,11 +131,12 @@ class ActionBehavior extends Behavior implements Cloneable {
             }
             playCount = (int)(time/motionLength);
             if ((loopFlag==false)&&(playCount>0)) {
-                if (elapsedTime<(time-motionLength))
+                if (previousTime>=motionLength-1)
                     return;
                 else
                     time = motionLength-1;
             }
+            previousTime = time;
             time = time % motionLength;
             double timeD = ((double)time)/1000.0;
             Action3DData.Action a = a3Data.actions[actionNo];
