@@ -34,6 +34,12 @@ public interface Motion {
      */
     public String getRootBone();
 
+    /**
+     * 指定されたBoneに接続されている親のBoneの名前を
+     * 文字列で返します。
+     */
+    public String getParentBone(String b);
+
     /**
      * 指定されたBoneに接続されている子のBoneの名前を
      * 文字列の配列で返します。
@@ -41,7 +47,10 @@ public interface Motion {
     public String[] getChildBones(String b);
 
     /**
-     * 指定された骨と時間における座標変換を返します。
+     * 指定された骨と時間における座標変換を返します。このメソッドによって
+     * 返される座標変換は関節の回転だけでなく、親の骨からのオフセットや
+     * 必要であれば拡大率なども含む最終的な合成された座標変換
+     * となっている必要がある点に注意して下さい。
      */
     public Transform3D getTransform3D(String bone,double time);
 }
