@@ -46,6 +46,11 @@ class ParserBVH extends DepthFirstAdapter {
         return rootBone;
     }
 
+    public String getParentBone(String b) {
+        Bone bone = bones.get(b);
+        return bone.parent;
+    }
+
     public String[] getChildBones(String b) {
         Bone bone = bones.get(b);
         return bone.children.clone();
@@ -58,18 +63,38 @@ class ParserBVH extends DepthFirstAdapter {
         frame = (frame>=frameCount)?frameCount-1:frame;
         return new Transform3D(b.transforms[frame]);
     }
-
+    // 指定された骨で設定されているHIERARCHYパートのオフセットを返す。
+    // モーションが付いていないデフォルトのポーズを構成するために使用する。
+    public Vector3d getOffset(String b) {
+        return new Vector3d(bones.get(b).offset);
+    }
+    //指定された骨の子供の骨で設定されているHIERARCHYパートのオフセットの一覧を返す。
+    //つまりは、この骨を描画する時に描画すべき線のtailの座標を返す。headは原点の
+    //座標になる。普通に骨が繋っている場合はここで返される複数の座標は同じ値に
+    //なるが、子供の骨がこの骨と離れている場合は、それぞれの子供の骨のheadに
+    //あたる座標がtailとして返されるということになる。
+    public ArrayList<Vector3d> getBoneTails(String b) {
+        ArrayList<Vector3d> boneTails = bones.get(b).boneTails;
+        if (boneTails==null)
+            return null; //ありえないはずだけど念のため
+        else
+            return new ArrayList<Vector3d>(boneTails);
+    }
     //最終的にBoneの情報を保存しておくためのクラス
     class Bone {
         String name;
+        String parent;
         String children[];
         Transform3D transforms[];
+        Vector3d offset = null;
+        ArrayList<Vector3d> boneTails = null;
     }
 
     //パースする時にBVHのBlockのデータをそのままの形で保存しておくための
     //クラス．Blockは最終的にはBoneに変換される．
     class Block {
         String name;
+        String parent;
         ArrayList<String> children;
         double  offsetX;
         double  offsetY;
@@ -83,6 +108,7 @@ class ParserBVH extends DepthFirstAdapter {
         Channel x_scale;
         Channel y_scale;
         Channel z_scale;
+        ArrayList<Vector3d> boneTails = new ArrayList<Vector3d>();
     }
 
     //Channelのデータを保存するためのクラス
@@ -142,6 +168,7 @@ class ParserBVH extends DepthFirstAdapter {
         t.blockQueue.add(t.currentBlock);
 
         t.currentBlock.name = node.getIdentifier().getText();
+        t.currentBlock.parent = null;
         t.currentBlock.children = new ArrayList<String>();
 
         node.getOffsetLine().apply(this);
@@ -158,9 +185,14 @@ class ParserBVH extends DepthFirstAdapter {
         PNumber y_number = node.getYOffset();
         PNumber z_number = node.getZOffset();
 
-        t.currentBlock.offsetX = pNumber2Double(x_number);
-        t.currentBlock.offsetY = pNumber2Double(y_number);
-        t.currentBlock.offsetZ = pNumber2Double(z_number);
+        double x = pNumber2Double(x_number);
+        double y = pNumber2Double(y_number);
+        double z = pNumber2Double(z_number);
+        t.currentBlock.offsetX = x;
+        t.currentBlock.offsetY = y;
+        t.currentBlock.offsetZ = z;
+        if (t.parentBlock!=null)
+            t.parentBlock.boneTails.add(new Vector3d(x,y,z));
     }
 
     public void caseAChannelsLine(AChannelsLine node) {
@@ -205,6 +237,7 @@ class ParserBVH extends DepthFirstAdapter {
         t.blockQueue.add(t.currentBlock);
 
         t.currentBlock.name = node.getIdentifier().getText();
+        t.currentBlock.parent = t.parentBlock.name;
         t.currentBlock.children = new ArrayList<String>();
 
         t.parentBlock.children.add(t.currentBlock.name);
@@ -481,8 +514,11 @@ class ParserBVH extends DepthFirstAdapter {
             Block block = i.next();
             Bone bone = new Bone();
             bone.name = block.name;
+            bone.parent = block.parent;
             bone.children = block.children.toArray(new String[0]);
             bone.transforms = new Transform3D[frameCount];
+            bone.offset = new Vector3d(block.offsetX,block.offsetY,block.offsetZ);
+            bone.boneTails = block.boneTails;
             for (int j=0;j<frameCount;j++) {
                 Transform3D t0 = new Transform3D();
                 t0.setTranslation(new Vector3d(block.offsetX,block.offsetY,block.offsetZ));
